Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // ErrInvalidID is returned when trying to unmarshal an invalid ID ErrInvalidID = errors.New("trid: invalid ID") )
Functions ¶
This section is empty.
Types ¶
type ID ¶
type ID [rawLen]byte
ID represents a unique request id
func FromString ¶
FromString reads an ID from its string representation
func (ID) MarshalJSON ¶
MarshalJSON implements encoding/json Marshaler interface
func (ID) MarshalText ¶
MarshalText implements encoding/text TextMarshaler interface
func (ID) String ¶
String returns a base32 hex lowercased with no padding representation of the id (char set is 0-9, a-v).
func (*ID) UnmarshalJSON ¶
UnmarshalJSON implements encoding/json Unmarshaler interface
func (*ID) UnmarshalText ¶
UnmarshalText implements encoding/text TextUnmarshaler interface
Click to show internal directories.
Click to hide internal directories.